/**
  *  \file planetscentral/dbclient/routerclient.cc
  *  \brief Client for c2router
  */

#include "planetscentral/dbclient/routerclient.h"
#include "planetscentral/dbclient/connection.h"

RouterClient::RouterClient()
    : host("127.0.0.1"), port("9999")
{ }

/** Call router.
    \param command Command. Must include the final newline. */
string_t
RouterClient::call(string_t command)
{
    Connection c;
    c.connect(host, port);
    c.send(command.data(), command.size());
    c.flush();

    string_t result;
    while (!c.isAtEnd()) {
        result += c.readChar();
    }
    return result;
}

/** Try to call router. Does not fail if router cannot be contacted.
    \param command Command. Must include the final newline. */
string_t
RouterClient::tryCall(string_t command)
{
    try {
        return call(command);
    }
    catch (...) {
        return string_t();
    }
}

void
RouterClient::setHost(string_t h)
{
    host = h;
}

void
RouterClient::setPort(string_t p)
{
    port = p;
}
